@@ -15,14 +15,13 @@
 # to the end flag
 import atexit
 import weakref
-import asyncio
 import itertools
 import threading
 import concurrent.futures.thread as _base
 
 from .future import Future 
 from .. import _get_parallel_context
-from ..asyncio import is_running_in_event_loop
+from ..asyncio import is_running_in_event_loop, asyncio
 
 _tasks_queues = weakref.WeakKeyDictionary()
 _shutdown = False
@@ -97,8 +96,16 @@ def _async_loop_thread(loop, stop_event):
     """Async loop thread.
     """
     asyncio.set_event_loop(loop)
+
     loop.run_until_complete(_loop_main(stop_event))
 
+    tasks = [task for task in asyncio.all_tasks(loop=loop)]
+    for task in tasks:
+        task.cancel()
+
+    loop.run_until_complete(asyncio.gather(*tasks, return_exceptions=True))
+    loop.close()
+
 
 class AsyncPoolExecutor(_base._base.Executor):
     """Async pool executor.
@@ -228,6 +235,8 @@ class SharedAsyncPoolExecutor(AsyncPoolExecutor):
     """Shared async pool executor.
     """
     def __init__(self, max_workers, task_name_prefix=""):
+        self.initargs = (max_workers, task_name_prefix) 
+
         if int(max_workers) < 0:
             raise ValueError("max_workers must be positive or 0")
         super(SharedAsyncPoolExecutor, self).__init__(
